Crate ntsync

Crate ntsync 

NTSync

for Wine the Ntsync driver was created to improve perfomance of Applications running with Wine. This is an implementation of the ioctls proviced by the device.

it is an implementation based on NTSync Docs

Structs

Event
An Event is an Type that can send Signals to other parts of the code. They can be automatically or manually reset. With manually reset events all waiting threads are worken up, but with automatically reset Event only one wakes up and can do the work.
EventStatus
Represents the Status of the Event at the moment of the Query.
Mutexmutex
An Mutex similar to std::sync::Mutex, but it can’t store Data.
MutexStatusmutex
Mutex Status is the Representation of the Status of the mutex at point of the query
NtSync
NtSync is an abstration over the Kernel API that is realised via ioctls.
NtSyncFlags
This helps Managing the Flags for waiting on Events.
OwnerId
An OwnerId is just an identifier for an part of the code which needs protections against parallel Access.
Semaphoresemaphore
An Semaphore. When the counter reaches 0 Threads will wait until one thread release an specific amount of resources.
SemaphoreStatussemaphore
SemaphoreStatus is the Status of the Semaphore at the time the read method was called.

Enums

Error
An Enum that is used to return different Errors from the Kernel. Since there is not much Information returned its mostly an simple enum.
EventSources
An Wrapper around the different Syncronisation Primitives of this crate

Traits

NTSyncObjects
NTSyncObjects is an Trait that combines all objects of the API.