MutexStatus

Struct MutexStatus 

pub struct MutexStatus { /* private fields */ }
Available on crate feature mutex only.
Mutex Status is the Representation of the Status of the mutex at point of the query

Implementations

Source

impl MutexStatus

pub fn owner(&self) -> Option<OwnerId>

The current Owner of the Mutex

pub fn depth(&self) -> Option<u32>

how many times the current owner has locked the Mutex.