NTSyncObjects

Trait NTSyncObjects 

pub trait NTSyncObjects:
    Sealed
    + Into<EventSources>
    + Clone
    + Copy {
    type Status;

    // Required methods
    fn delete(self) -> Result<(), Error>;
    fn read(&self) -> Result<Self::Status, Error>;
}
NTSyncObjects is an Trait that combines all objects of the API.

Required Associated Types

type Status

The Status represents the status of the object at the time the read method call returned. It must not be shared across threads.

Required Methods

fn delete(self) -> Result<(), Error>

Deletes the object. All copies of this object are now invalid and return the Error::InvalidValue Enum item.

fn read(&self) -> Result<Self::Status, Error>

Reads the status of the object

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl NTSyncObjects for Event

Source

impl NTSyncObjects for Mutex

Available on crate feature mutex only.
Source

impl NTSyncObjects for Semaphore

Available on crate feature semaphore only.